/*******************************************************************************
 FILE	: ADS8342.h
 DESC	: main.c header file
 *******************************************************************************/

// Set clock speed and sample size
#define CONVCLK_PERIOD		3 // = 1.013us pulse
#define ADC_SAMPLE_SIZE		1024

// Note - W5 is located on the 5-6K Interface Board
// W5 open selects upper address space (A14 - A17)
// W5 closed selects lower address space (A2 - A5)
#define W5_Closed		0  

/*******************************************************************************
 Extern labels
 *******************************************************************************/
extern unsigned int intvectable;


/*******************************************************************************
 Defines
 *******************************************************************************/

// Timers
#define TIMER_Run(x)		*(unsigned volatile int *)(x) = 0x03C3
#define TIMER_Stop(x)		*(unsigned volatile int *)(x) &= 0xff3f
#define TIMER_StopFast(x)	*(unsigned volatile int *)(x) = 0x0303

// Interrupts
#define INT_POLARITY		0x019c0008
#define	INT_EXT4			0x0010
#define	INT_TIMER0			0x4000

// LEDs
#define USER_LEDS_Off		*(unsigned volatile int *)IO_PORT = 0x07000000
#define USER_LEDS_On		*(unsigned volatile int *)IO_PORT = 0x00000000
#define USER_LED1_On		*(unsigned volatile int *)IO_PORT = 0x06000000
#define USER_LED2_On		*(unsigned volatile int *)IO_PORT = 0x05000000
#define USER_LED3_On		*(unsigned volatile int *)IO_PORT = 0x03000000

// Software controlled operation of the ADS8342
 #define A0				0x00
 #define A1				0x01
 #define B0				0x02
 #define B1				0x03

// ADC Address
#if (W5_Closed)
 #define ADC_Base	0xa0000008
 #define _CH0		0xa0000008		    /* Channel 0	*/
 #define _CH1		0xa0000018		    /* Channel 1	*/
 #define _CH2		0xa0000028			/* Channel 2	*/
 #define _CH3		0xa0000038			/* Channel 3	*/

#else
 #define ADC_Base	0xa0008000
 #define _CH0		0xa0008000		    /* Channel 0	*/
 #define _CH1		0xa0018000		    /* Channel 1	*/
 #define _CH2		0xa0028000			/* Channel 2	*/
 #define _CH3		0xa0038000			/* Channel 3	*/
#endif

/*******************************************************************************
 Function prototypes
 *******************************************************************************/
void delay();
void hardware_init_ADC();
void read_ADC(unsigned int channel);
void soft_cnvt(unsigned int channel);
interrupt void ext4_isr();


