/*******************************************************************************
 FILE	: Main.c				(C)Copyrights 2003 Texas Instruments, Inc.
 AUTHOR	: T. Hendrick
 Date   : 2003-06-01
 DESC	: This program is a simple example which excercises the 4 channel 
 		  ADS8342 with the C6711DSK.
 CCS Ver: 2.20.11 		  
 *******************************************************************************/
#include "ADS8342.h"
#include "ADS8342cfg.h"


/*******************************************************************************
 Program Controls
 *******************************************************************************/
#define BYTE_Mode	(0)

/*******************************************************************************
 Scope variables
 *******************************************************************************/
unsigned int adc_ready;							// Set when ADC frame is done
unsigned int adc_readNdx;						// A/D read index

unsigned short int CH0_temp[ADC_SAMPLE_SIZE];
unsigned short int CH1_temp[ADC_SAMPLE_SIZE];
unsigned short int CH2_temp[ADC_SAMPLE_SIZE];
unsigned short int CH3_temp[ADC_SAMPLE_SIZE];
unsigned short int ADC_address[4];
int ch;

/*******************************************************************************
 FUNC	: main
 DESC	: Initialize the board and start the program
 ARGS	: void
 RET	: void
 *******************************************************************************/
int main()
{

  // Prepare ADC and start conversions through Hardware
	hardware_init_ADC();

  // Enable Interrupt to catch EOC pulses
	HWI_enable();
	IRQ_enable(IRQ_EVT_EXTINT4);
  // Main never ending loop
	ch = 0;
	while(1) 
	{
	  if (adc_ready)
	  {
    	soft_cnvt(ch);
		adc_ready = 0;
	  }
	}
}

/*******************************************************************************
 FUNC	: hardware_init__adc
 DESC	: Prepare the system for the ADC conversions. Everything is set up to
 		  wait the CONV CLK start running (TIMER1).  Ensure timer jumper is set
 		  to "TOUTb" on 5-6K Interface.
 ARGS	: void
 RET	: void
 *******************************************************************************/
void hardware_init_ADC()
{
  // Initialize vars
	adc_ready   = 0;
    adc_readNdx = 0;
    adc_ready   = 1;
    TIMER_start(hTimer1);
}

/*******************************************************************************
 FUNC	: soft_cnvt
 DESC	: Write to the ADC to initiate Conversion Cycle
 ARGS	: channel to convert
 RET	: void
 *******************************************************************************/
void soft_cnvt(unsigned int channel)
{
    switch (channel)
    {

        case  0:
  			*(unsigned volatile int *)_CH0 = 0x00;
            break;
        case  1:
  			*(unsigned volatile int *)_CH1 = 0x00;
            break;
        case  2:
  			*(unsigned volatile int *)_CH2 = 0x00;
            break;
        case  3:
  			*(unsigned volatile int *)_CH3 = 0x00;
            break;   
     }                         	
}

/*******************************************************************************
 FUNC	: read_ADC
 DESC	: Read the converted data - called from ISR
 ARGS	: channel to read
 RET	: void
 *******************************************************************************/
void read_ADC(unsigned int channel)
{
    switch (channel)
    {
        case  0:
  			CH0_temp[adc_readNdx] =*(unsigned volatile int *)_CH0;
            break;
        case  1:
            CH1_temp[adc_readNdx] =*(unsigned volatile int *)_CH1;
            break;
        case  2:
            CH2_temp[adc_readNdx] =*(unsigned volatile int *)_CH2;
            break;
        case  3:
            CH3_temp[adc_readNdx] =*(unsigned volatile int *)_CH3;
            break;
    }
	adc_readNdx = adc_readNdx+1;
	adc_ready = 1;
	if(adc_readNdx == ADC_SAMPLE_SIZE)
	 { 
	   adc_readNdx = 0;  //Insert Probe Point here for data display
	   ch=ch+1;
	   if(ch == 4){ch = 0;}
	 }	
}

/*******************************************************************************
 FUNC	: ext4_isr()
 DESC	: EXT4 interrupt routine. Called when ADS8342 generates the EOC pulse.
 ARGS	: void
 RET	: void
 *******************************************************************************/
interrupt void ext4_isr()
{
	read_ADC(ch);
}  

/*******************************************************************************
 FUNC	: delay()
 DESC	: Create a delay
 ARGS	: time = extra cycles
 RET	: void
 *******************************************************************************/
void delay(int time)
{
int i;
for (i=0; i<time; i++);
}
// End of file
